;; Generated package description from org-gnosis.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "org-gnosis" "0.2.1.0.20260223.80638" "Learning-focused note-taking for Gnosis" '((emacs "27.2") (emacsql "4.0.0") (compat "29.1.4.2")) :commit "52b7b4383053b88f98aae5b2651f4ad5e3d69a95" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("outlines" "extensions" "org-mode") :url "https://thanosapollo.org/projects/org-gnosis/")
